==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PA/ts/Arc2PA_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Arc2PA</name>
    <message>
        <location filename="../Arc2PA.js" line="+65"/>
        <source>Start point</source>
        <translation>起始点</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End point</source>
        <translation>结束点</translation>
    </message>
    <message>
        <location line="+85"/>
        <source>Invalid angle</source>
        <translation>无效角度</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>两个点完全相同</translation>
    </message>
    <message>
        <location filename="../Arc2PA.ui" line="+17"/>
        <source>Angle:</source>
        <translation>角度：</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>方向：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>逆时针方向（正向）</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>方向</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>顺时针方向（反向）</translation>
    </message>
    <message>
        <location filename="../Arc2PAInit.js" line="+2"/>
        <source>&amp;2 Points and Angle</source>
        <translation>点和角度(&amp;2)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and angle</source>
        <translation>以两点和角度画弧</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PA/ts/Arc2PA_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Arc2PA</name>
    <message>
        <location filename="../Arc2PA.js" line="+65"/>
        <source>Start point</source>
        <translation>起点</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End point</source>
        <translation>终点</translation>
    </message>
    <message>
        <location line="+85"/>
        <source>Invalid angle</source>
        <translation>无效角度</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>两个点完全相同</translation>
    </message>
    <message>
        <location filename="../Arc2PA.ui" line="+17"/>
        <source>Angle:</source>
        <translation>角度：</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>方向：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>逆时针（正向）</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>方向</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>顺时针（负向）</translation>
    </message>
    <message>
        <location filename="../Arc2PAInit.js" line="+2"/>
        <source>&amp;2 Points and Angle</source>
        <translation>两点和角度(&amp;2)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and angle</source>
        <translation>以两点和角度画弧</translation>
    </message>
</context>
</TS>
